/*
 ** Versão em Português
 ** Traduzido por Élton Reisdorfer
 ** WebSite: http://eltonrst.tk
 ** Facebook : http://facebook.com/elton.reisdorfer
 */
AmCharts.translations["export"]["pt"] = {
    "fallback.save.text": "CTRL + C para copiar os dados para a área de transferência.",
    "fallback.save.image": "Clique Direito -> Salvar imagem como... para salvar a imagem.",

    "capturing.delayed.menu.label": "{{duration}}",
    "capturing.delayed.menu.title": "Clique para cancelar",

    "menu.label.print": "Imprimir",
    "menu.label.undo": "Desfazer",
    "menu.label.redo": "Refazer",
    "menu.label.cancel": "Cancelar",

    "menu.label.save.image": "Baixar Como",
    "menu.label.save.data": "Salvar Como",

    "menu.label.draw": "Editar",
    "menu.label.draw.change": "Alterar",
    "menu.label.draw.add": "Adicionar",
    "menu.label.draw.shapes": "Forma",
    "menu.label.draw.colors": "Cor",
    "menu.label.draw.widths": "Tamanho",
    "menu.label.draw.opacities": "Tranparência",
    "menu.label.draw.text": "Texto",

    "menu.label.draw.modes": "Ferramenta",
    "menu.label.draw.modes.pencil": "Pincel",
    "menu.label.draw.modes.line": "Linha",
    "menu.label.draw.modes.arrow": "Seta",

    "label.saved.from": "Salvar de: "
}
